---
title: <span class="badge object-type-scalar"></span> Millibars
---
# <span class="badge object-type-scalar"></span> Millibars

Pressure: Millibars

## Definition

```python
# Pressure: Millibars
Millibars: typing.Literal["pressurembar"] = "pressurembar"
```
